@@ -45,10 +45,37 @@ class AppHandler(object):
 
     aka. "one handler to bind them all"
     """
+    default_autocompleters = {
+        'brands': 'rattail.autocomplete.brands:BrandAutocompleter',
+        'customers': 'rattail.autocomplete.customers:CustomerAutocompleter',
+        'customers.phone': 'rattail.autocomplete.customers:CustomerPhoneAutocompleter',
+        'employees': 'rattail.autocomplete.employees:EmployeeAutocompleter',
+        'departments': 'rattail.autocomplete.departments:DepartmentAutocompleter',
+        'people': 'rattail.autocomplete.people:PersonAutocompleter',
+        'people.employees': 'rattail.autocomplete.people:PersonEmployeeAutocompleter',
+        'products': 'rattail.autocomplete.products:ProductAutocompleter',
+        'products.all': 'rattail.autocomplete.products:ProductAllAutocompleter',
+        'vendors': 'rattail.autocomplete.vendors:VendorAutocompleter',
+    }
 
     def __init__(self, config):
         self.config = config
 
+    def get_autocompleter(self, key, **kwargs):
+        """
+        Returns an Autocompleter instance corresponding to the given
+        key.  Config may determine where the Autocompleter class
+        lives, or there are some defaults registered within the app
+        handler which may be used.
+        """
+        spec = self.config.get('rattail', 'autocomplete.{}'.format(key))
+        if not spec:
+            spec = self.default_autocompleters.get(key)
+        if spec:
+            return load_object(spec)(self.config)
+
+        raise NotImplementedError("cannot locate autocompleter for key: {}".format(key))
+
     def get_board_handler(self, **kwargs):
         if not hasattr(self, 'board_handler'):
             from rattail.board import get_board_handler
@@ -192,6 +219,14 @@ class AppHandler(object):
         if len(normal) != 10:
             return "Phone number must have 10 digits"
 
+    def format_phone_number(self, number):
+        """
+        Returns a "properly formatted" string based on the given phone number.
+        """
+        from rattail.db.util import format_phone_number
+
+        return format_phone_number(number)
+
     def render_currency(self, value, scale=2, **kwargs):
         """
         Must return a human-friendly display string for the given currency
