@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -187,8 +187,10 @@ class BatchMixin(object):
 
     @property
     def id_str(self):
+        from rattail.batch import batch_id_str
+
         if self.id:
-            return "{:08d}".format(self.id)
+            return batch_id_str(self.id)
         return ''
 
     def __str__(self):
