@@ -536,8 +536,10 @@ class Purchase(PurchaseBase, Base):
 
     @property
     def id_str(self):
+        from rattail.batch import batch_id_str
+
         if self.id:
-            return "{:08d}".format(self.id)
+            return batch_id_str(self.id)
         return ""
 
 
