@@ -172,6 +172,9 @@ class ToCSV(ToFile):
         else: # PY3
             self.output_file = open(self.output_file_path, 'wt', encoding='utf_8')
             self.output_writer = csv.DictWriter(self.output_file, self.fields)
+        self.write_output_header()
+
+    def write_output_header(self):
         self.output_writer.writeheader()
 
     def close_output_file(self):
